@@ -94,7 +94,7 @@ Text::Xslate::Bridge - The interface base class to import methods
 
     use parent qw(Text::Xslate::Bridge);
 
-    __PACKAGE__->bride(
+    __PACKAGE__->bridge(
         nil    => \%nil_methods,
         scalar => \%scalar_methods,
         array  => \%array_methods,
@@ -118,12 +118,20 @@ Text::Xslate::Bridge - The interface base class to import methods
 
 This module is the base class for adaptor classes.
 
+=head1 INTERFACE
+
+=head2 C<< __PACKAGE__->bridge(@mapping) :Void >>
+
+Install a bridge module that has method I<@mapping>.
+
 =head1 SEE ALSO
 
 L<Text::Xslate>
 
 L<Text::Xslate::Bridge::TT2>
 
+L<Text::Xslate::Bridge::TT2::Like>
+
 L<Text::Xslate::Bridge::Alloy>
 
 
